BN: afs
SF: afs.c aft.c attribute.c
SN: list of afs commands
TM: mood lyr img pl
---
N: add
P: AFS_READ | AFS_WRITE
D: Add or update audio files.
U: add [-a] [-l] [-f] [-v] path...
H: Each path must be absolute and refer to either an audio file, or a
H: directory. In case of a directory, all audio files in that directory
H: are added recursively. Only absolute paths are accepted.
H:
H: Options:
H:
H: -a	Add all files. The default is to add only files ending in a
H:	known suffix for a supported audio format.
H:
H: -l	Add files lazily. If the path already exists in the
H:	database, skip this file.  This operation is really cheap. Useful
H:	to update large directories after some files have been added or
H:	deleted.
H:
H: -f	Force adding/updating. Recompute the audio format handler data
H: 	even if a file with the same path and the same hash value exists.
H:
H: -v	Verbose mode. Print what is being done.
---
N: init
P: AFS_READ | AFS_WRITE
D: Initialize the osl tables for the audio file selector.
U: init [table_name ...]
H: When invoked without arguments, this command creates all tables. Otherwise
H: only the tables given by table_name... are created.
---
N: ls
P: AFS_READ
D: List audio files.
U: ls [-l=mode] [-p] [-a] [-r] [-d] [-s=order] [pattern...]
H: Print a list of all audio files matching pattern.
H:
H: Options:
H:
H: -l=mode	Change listing mode. Defaults to short listing if not given.
H:
H:    Available modes:
H:    s: short listing mode
H:    l: long listing mode (equivalent to -l)
H:    v: verbose listing mode
H:    p: parser-friendly mode
H:    m: mbox listing mode
H:    c: chunk-table listing mode
H:
H: -F	List full paths. If this option is not specified, only the basename
H:	of each file is printed.
H: -p	Synonym for -F. Deprecated.
H:
H: -b	Print only the basename of each matching file. This is the default, so
H:	the option is currently a no-op. It is recommended to specify this option,
H:	though, as the default might change in a future release.
H:
H: -a	List only files that are admissible with respect to the current mood or
H:	playlist.
H:
H: -r	Reverse sort order.
H:
H: -d	Print dates as seconds after the epoch.
H:
H: -s=order
H:	Change sort order. Defaults to alphabetical path sort if not given.
H:
H:   Possible values for order:
H:   p: by path
H:   l: by last played time
H:   s: by score (implies -a)
H:   n: by num played count
H:   f: by frequency
H:   c: by number of channels
H:   i: by image id
H:   y: by lyrics id
H:   b: by bit rate
H:   d: by duration
H:   a: by audio format
---
N: lsatt
P: AFS_READ
D: List attributes.
U: lsatt [-i] [-l] [-r] [pattern]
H: Print the list of all defined attributes which match the given
H: pattern. If no pattern is given, the full list is printed.
H:
H: Options:
H:
H: -i	Sort attributes by id. The default is to sort alphabetically by name.
H:
H: -l	Print a long listing containing both identifier and attribute name. The
H: 	default is to print only the name.
H:
H: -r	Reverse sort order.
---
N: setatt
P: AFS_READ | AFS_WRITE
D: Set attribute(s) for all files matching a pattern.
U: setatt attribute{+|-}... pattern
H: Set ('+') or unset ('-') the given attributes for all audio files matching
H: pattern.  Example:
H:
H:         setatt rock+ punk+ pop- '*foo.mp3'
H:
H: sets the 'rock' and the 'punk' attribute and unsets the 'pop'
H: attribute of all files ending with 'foo.mp3'.
---
N: addatt
P: AFS_READ | AFS_WRITE
D: Add new attribute(s).
U: addatt attribute1...
H: This adds new attributes to the attribute table. At most 64
H: attributes may be defined.
---
N: mvatt
P: AFS_READ | AFS_WRITE
D: Rename an attribute.
U: mvatt old new
H: Rename attribute old to new.
---
N: check
P: AFS_READ
D: Run integrity checks against osl tables.
U: check [-a] [-A] [-m] [-p]
H: Check the audio file table, the attribute table, the mood definitions
H: and all defined playlists. Report any inconsistencies.
H:
H: Options:
H:
H: -a 	Run audio file table checks. Checks for entries in the audio file
H: 	table which are not present in the file system. Moreover, it checks
H: 	whether the lyrics id and all entries in the audio file table are
H: 	valid.
H:
H: -A	Check the attribute table against the afs attribute bitmask of
H:	each audio file in the audio file table. Reports audio files
H:	whose attribute bitmask is invalid, i.e., has a bit set which
H:	does not correspond to any attribute of the attribute table.
H:
H: -m	Run syntax checks on all defined moods in the mood table.
H:
H: -p	Check all playlists for lines that correspond to files not contained
H: 	in the audio file table.
H:
H: If called without arguments, all checks are run.
---
N: rmatt
P: AFS_READ | AFS_WRITE
D: Remove attribute(s).
U: rmatt pattern...
H: Remove all attributes matching any given pattern. All information
H: about this attribute in the audio file table is lost.
---
N: rm
P: AFS_READ | AFS_WRITE
D: Remove entries from the audio file table.
U: rm [-v] [-f] [-p] pattern...
H: Delete all entries in the audio file table that match any given pattern.  Note
H: that this affects the table entries only; the command won't touch your audio
H: files on disk.
H:
H: Options:
H:
H: -v	Verbose mode. Explain what is being done.
H:
H: -f	Force mode. Ignore nonexistent files. Don't complain if nothing
H:	was removed.
H:
H: -p	Pathname match. Match a slash in the path only with a slash
H: 	in pattern and not by an asterisk (*) or a question mark
H: 	(?) metacharacter, nor by a bracket expression ([]) containing
H: 	a slash (see fnmatch(3)).
---
N: touch
P: AFS_READ | AFS_WRITE
D: Manipulate the afs entry of audio files.
U: touch [-n=numplayed] [-l=lastplayed] [-y=lyrics_id] [-i=image_id] [-a=amp] [-v] [-p] pattern
H: If no option is given, the lastplayed field is set to the current time
H: and the value of the numplayed field is increased by one. Otherwise,
H: only the given options are taken into account.
H:
H: Options:
H:
H: -n	Set the numplayed count, i.e. the number of times this audio
H:	file was selected for streaming so far.
H:
H: -l	Set the lastplayed time, i.e. the last time this audio file was
H:	selected for streaming. The argument must be a number of seconds
H:	since the epoch. Example:
H:
H: 		touch -l=$(date +%s) file
H:
H: 	sets the lastplayed time of 'file' to the current time.
H:
H: -y	Set the lyrics ID which specifies the lyrics data file associated
H:	with the audio file.
H:
H: -i	Like -y, but sets the image ID.
H:
H: -a	Set the amplification value (0-255). This determines a scaling
H:	factor by which the amplitude should be multiplied in order to
H:	normalize the volume of the audio file.  A value of zero means
H:	no amplification, 64 means the amplitude should be multiplied
H:	by a factor of two, 128 by three and so on.
H:
H:	This value is used by the amp filter.
H:
H: -v	Verbose mode. Explain what is being done.
H:
H: -p	Pathname match. Match a slash in the path only with a slash
H: 	in pattern and not by an asterisk (*) or a question mark
H: 	(?) metacharacter, nor by a bracket expression ([]) containing
H: 	a slash (see fnmatch(3)).
---
N: cpsi
P: AFS_READ | AFS_WRITE
D: Copy audio file selector info.
U: cpsi [-a] [-y] [-i] [-l] [-n] [-v] source pattern...
H: If no option, or only the -v option is given, all fields of the
H: audio file selector info are copied to all files matching pattern.
H: Otherwise, only the given options are taken into account.
H:
H: Options:
H:
H: -a	Copy attributes.
H:
H: -y	Copy the lyrics id.
H:
H: -i	Copy the image id.
H:
H: -l	Copy the lastplayed time.
H:
H: -n	Copy the numplayed count.
H:
H: -v	Verbose mode.
---
N: select
P: AFS_READ | AFS_WRITE
D: Activate a mood or a playlist.
U: select specifier/name
H: The specifier is either 'm' or 'p' to indicate whether a playlist or
H: a mood should be activated. Example:
H:
H:	select m/foo
H:
H: loads the mood named 'foo'.
---
T: add
N: add@member@
O: int com_add@member@(struct command_context *cc);
P: AFS_READ | AFS_WRITE
D: Add stdin as a blob to the @member@ table.
U: add@member@ @member@_name
H: Read from stdin and ask the audio file selector to create a blob in the
H: corresponding osl table. If the named blob already exists, it gets replaced
H: with the new data.
---
T: cat
N: cat@member@
O: int com_cat@member@(struct command_context *cc);
P: AFS_READ
D: Dump the contents of a blob of type @member@ to stdout.
U: cat@member@ @member@_name
H: Retrieve the named blob and write it to stdout.
---
T: ls
N: ls@member@
O: int com_ls@member@(struct command_context *cc);
P: AFS_READ
D: List blobs of type @member@ which match a pattern.
U: ls@member@ [-i] [-l] [-r] [pattern]
H: Print the list of all blobs which match the given pattern. If no
H: pattern is given, the full list is printed.
H:
H: Options:
H:
H: -i	Sort by identifier. The default is to sort alphabetically by name.
H:
H: -l	Print identifier and name. The default is to print only the name.
H:
H: -r	Reverse sort order.
---
T: rm
N: rm@member@
O: int com_rm@member@(struct command_context *cc);
P: AFS_READ | AFS_WRITE
D: Remove blob(s) of type @member@ from the @member@ table.
U: rm@member@ pattern...
H: Remove all blobs whose name matches any of the given patterns.
---
T: mv
N: mv@member@
O: int com_mv@member@(struct command_context *cc);
P: AFS_READ | AFS_WRITE
D: Rename a blob of type @member@.
U: mv@member@ source_@member@_name dest_@member@_name
H: Rename the blob identified by the source blob name to the destination blob
H: name. The command fails if the source does not exist, or if the destination
H: already exists.
